@@ -1,14 +1,10 @@
-import six
+from enum import Enum
+
 from sqlalchemy import types
 
 from ..exceptions import ImproperlyConfigured
 from .scalar_coercible import ScalarCoercible
 
-try:
-    from enum import Enum
-except ImportError:
-    Enum = None
-
 
 class Choice(object):
     def __init__(self, code, value):
@@ -20,11 +16,14 @@ class Choice(object):
             return self.code == other.code
         return other == self.code
 
+    def __hash__(self):
+        return hash(self.code)
+
     def __ne__(self, other):
         return not (self == other)
 
-    def __unicode__(self):
-        return six.text_type(self.value)
+    def __str__(self):
+        return str(self.value)
 
     def __repr__(self):
         return 'Choice(code={code}, value={value})'.format(
@@ -33,7 +32,7 @@ class Choice(object):
         )
 
 
-class ChoiceType(types.TypeDecorator, ScalarCoercible):
+class ChoiceType(ScalarCoercible, types.TypeDecorator):
     """
     ChoiceType offers way of having fixed set of choices for given column. It
     could work with a list of tuple (a collection of key-value pairs), or
@@ -62,7 +61,7 @@ class ChoiceType(types.TypeDecorator, ScalarCoercible):
 
 
         user = User(type=u'admin')
-        user.type  # Choice(type='admin', value=u'Admin')
+        user.type  # Choice(code='admin', value=u'Admin')
 
     Or::
 
@@ -106,7 +105,7 @@ class ChoiceType(types.TypeDecorator, ScalarCoercible):
 
 
         user = User(type=u'admin')
-        user.type  # Choice(type='admin', value=u'Admin')
+        user.type  # Choice(code='admin', value=u'Admin')
 
         print user.type  # u'Admin'
 
@@ -141,7 +140,7 @@ class ChoiceType(types.TypeDecorator, ScalarCoercible):
     impl = types.Unicode(255)
 
     def __init__(self, choices, impl=None):
-        self.choices = choices
+        self.choices = tuple(choices) if isinstance(choices, list) else choices
 
         if (
             Enum is not None and
@@ -214,10 +213,14 @@ class EnumTypeImpl(object):
         self.enum_class = enum_class
 
     def _coerce(self, value):
-        return self.enum_class(value) if value else None
+        if value is None:
+            return None
+        return self.enum_class(value)
 
     def process_bind_param(self, value, dialect):
-        return self.enum_class(value).value if value else None
+        if value is None:
+            return None
+        return self.enum_class(value).value
 
     def process_result_value(self, value, dialect):
-        return self.enum_class(value) if value else None
+        return self._coerce(value)
